=== added directory 'apt-update'
=== added file 'apt-update/Makefile'
--- apt-update/Makefile	1970-01-01 00:00:00 +0000
+++ apt-update/Makefile	2011-11-04 11:42:10 +0000
@@ -0,0 +1,7 @@
+NAME = apt-update
+
+$(NAME): $(NAME).c
+	$(CC) $(CFLAGS) -Wall $< -o $@
+
+clean:
+	rm -f $(NAME)

=== added file 'apt-update/apt-update.c'
--- apt-update/apt-update.c	1970-01-01 00:00:00 +0000
+++ apt-update/apt-update.c	2011-11-04 11:42:10 +0000
@@ -0,0 +1,75 @@
+#define _GNU_SOURCE
+#include <sys/resource.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <grp.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
+#include <errno.h>
+#include <stdio.h>
+#include <pwd.h>
+
+int main(int argc, char *argv[], char *envp[])
+{
+  char *apt_argv[] = {"/usr/bin/apt-get", "-q", "update", NULL};
+  char *apt_envp[] = {"PATH=/bin:/usr/bin", NULL, NULL};
+
+  // Set the HOME environment variable
+  struct passwd *pwd = getpwuid(geteuid());
+  if (!pwd) {
+    fprintf(stderr, "error: Unable to find passwd entry for uid %d (%s)\n",
+            geteuid(), strerror(errno));
+    exit(1);
+  }
+  if (asprintf(&apt_envp[1], "HOME=%s", pwd->pw_dir) == -1) {
+    perror("error: Unable to create HOME environment variable");
+    exit(1);
+  }
+
+  // Drop any supplementary group
+  if (setgroups(0, NULL) == -1) {
+    perror("error: Unable to set supplementary groups IDs");
+    exit(1);
+  }
+
+  // Set real/effective gid and uid
+  if (setregid(pwd->pw_gid, pwd->pw_gid) == -1) {
+    fprintf(stderr, "error: Unable to set real and effective gid (%s)\n",
+            strerror(errno));
+    exit(1);
+  }
+  if (setreuid(pwd->pw_uid, pwd->pw_uid) == -1) {
+    perror("error: Unable to set real and effective uid");
+    exit(1);
+  }
+
+  // Close all file descriptors except the standard ones
+  struct rlimit rlp;
+  if (getrlimit(RLIMIT_NOFILE, &rlp) == -1) {
+    perror("error: Unable to determine file descriptor limits");
+    exit(1);
+  }
+  int file_max;
+  if (rlp.rlim_max == RLIM_INFINITY || rlp.rlim_max > 4096)
+    file_max = 4096;
+  else
+    file_max = rlp.rlim_max;
+  int file;
+  for (file = 3; file < file_max; file++) {
+    close(file);
+  }
+
+  // Set umask to 022
+  umask(S_IWGRP | S_IWOTH);
+
+  if (chdir("/") == -1) {
+    perror("error: Unable to change working directory");
+    exit(1);
+  }
+
+  // Run apt-get update
+  execve(apt_argv[0], apt_argv, apt_envp);
+  perror("error: Unable to execute apt-get");
+  return 1;
+}

=== modified file 'debian/landscape-client.postinst'
--- debian/landscape-client.postinst	2011-10-07 11:52:47 +0000
+++ debian/landscape-client.postinst	2011-11-04 11:42:10 +0000
@@ -102,12 +102,17 @@
             echo "Old monolithic client data file migrated to new format."
         fi
 
-        # Add the setuid flag to smart-update and it be executable by users in
-        # the landscape group (that normally means landscape itself)
+        # Add the setuid flag to smart-update and apt-update, and make them be
+        # executable by users in the landscape group (that normally means
+        # landscape itself)
         smart_update=/usr/lib/landscape/smart-update
         if ! dpkg-statoverride --list $smart_update >/dev/null 2>&1; then
             dpkg-statoverride --update --add root landscape 4754 $smart_update
         fi
+        apt_update=/usr/lib/landscape/apt-update
+        if ! dpkg-statoverride --list $apt_update >/dev/null 2>&1; then
+            dpkg-statoverride --update --add root landscape 4754 $apt_update
+        fi
 
         # Remove old cron jobs
         old_cron_job=/etc/cron.hourly/landscape-client

=== modified file 'debian/landscape-client.prerm'
--- debian/landscape-client.prerm	2009-06-08 13:29:20 +0000
+++ debian/landscape-client.prerm	2011-11-04 11:42:10 +0000
@@ -20,11 +20,15 @@
 case "$1" in
     remove|upgrade|deconfigure)
 
-        # Remove statoverride for smart-update
+        # Remove statoverride for smart-update and apt-update
         smart_update=/usr/lib/landscape/smart-update
         if dpkg-statoverride --list $smart_update >/dev/null 2>&1; then
             dpkg-statoverride --remove $smart_update
         fi
+        apt_update=/usr/lib/landscape/apt-update
+        if dpkg-statoverride --list $apt_update >/dev/null 2>&1; then
+            dpkg-statoverride --remove $apt_update
+        fi
 
     ;;
 

=== modified file 'debian/rules'
--- debian/rules	2011-04-26 09:47:16 +0000
+++ debian/rules	2011-11-04 11:42:10 +0000
@@ -30,6 +30,7 @@
 	sed -i -e "s/^DEBIAN_REVISION = \"\"/DEBIAN_REVISION = \"-$(revision)\"/g" landscape/__init__.py
 	python setup.py build
 	make -C smart-update
+	make -C apt-update
 	touch build-stamp
 
 clean:
@@ -38,6 +39,7 @@
 	rm -f build-stamp
 	rm -rf build
 	make -C smart-update clean
+	make -C apt-update clean
 	dh_clean
 	debconf-updatepo
 	sed -i -e "s/^DEBIAN_REVISION = .*/DEBIAN_REVISION = \"\"/g" landscape/__init__.py
@@ -57,6 +59,7 @@
 	install -D -o root -g root -m 755 debian/landscape-sysinfo.wrapper $(root_dir)/usr/share/landscape/landscape-sysinfo.wrapper
 	install -D -o root -g root -m 644 debian/cloud-default.conf $(root_dir)/usr/share/landscape/cloud-default.conf
 	install -D -o root -g root -m 755 smart-update/smart-update $(root_dir)/usr/lib/landscape/smart-update
+	install -D -o root -g root -m 755 apt-update/apt-update $(root_dir)/usr/lib/landscape/apt-update
 	install -D -o root -g root -m 644 dbus/landscape.conf $(root_dir)/etc/dbus-1/system.d/landscape.conf
 
 binary-indep:

